#!/bin/bash

# Destination directories
BINDIR="/usr/local/bin"
CGIDIR="/usr/lib/cgi-bin"
DATADIR="/var/local/lib/websearch"
DOCDIR="/usr/local/share/doc/websearch"
FORMDIR="/var/www/search"
MANDIR="/usr/local/share/man/man1"

# Copy and strip if newer
copy_bin() {
	# Original Path/File from tar
	ORIG="${1}"
	# Copy to this dir
	DIR="${2}"
	# Just the filename
	FILE=$( basename "${ORIG}" )
	if ! [ -f "${DIR}/${FILE}" ] || [ "${ORIG}" -nt "${DIR}/${FILE}" ]
	then
		cp "${ORIG}" "${DIR}/"
		strip "${DIR}/${FILE}"
	fi
}

# Copy and gzip man page if newer
copy_man() {
	# Original Path/File from tar
	ORIG="${1}"
	# Copy to this dir
	DIR="${2}"
	# Just the filename
	FILE=$( basename "${ORIG}" )
	if ! [ -f "${DIR}/${FILE}.gz" ] || [ "${ORIG}" -nt "${DIR}/${FILE}.gz" ]
	then
		cp "${ORIG}" "${DIR}/"
		gzip -f "${DIR}/${FILE}"
	fi
}

# Check UID
if [ "${UID}" -ne 0 ]
then
	echo "You need to be root to install."
	echo "Aborting install."
	exit 1
fi

# Install binaries and scripts
if [ ! -d "${BINDIR}" ]
then
	echo "Creating dir ${BINDIR}."
	mkdir -p "${BINDIR}"
fi
if [ ! -d "${CGIDIR}" ]
then
	echo "Creating dir ${CGIDIR}"
	mkdir -p "${CGIDIR}"
fi
echo "Copying binaries."
copy_bin cgi-index "${BINDIR}"
copy_bin cgi-search "${CGIDIR}"
copy_bin fndtitle "${BINDIR}"
copy_bin gen-num-index "${BINDIR}"
copy_bin gensynontab "${BINDIR}"
copy_bin url2file "${BINDIR}"
echo "Copying scripts."
cp -u scripts/* "${BINDIR}/"

# Install doc
if [ ! -d "${DOCDIR}" ]
then
	echo "Creating dir ${DOCDIR}."
	mkdir -p "${DOCDIR}"
fi
echo "Copying doc"
cp -u doc/* "${DOCDIR}/"

# Install man pages
if [ ! -d "${MANDIR}" ]
then
	echo "Creating dir ${MANDIR}."
	mkdir -p "${MANDIR}"
fi
echo "Copying man pages."
copy_man man/cgi-index.1 "${MANDIR}"
copy_man man/cgi-search.1 "${MANDIR}"
copy_man man/fndtitle.1 "${MANDIR}"
copy_man man/gen-num-index.1 "${MANDIR}"
copy_man man/gensynontab.1 "${MANDIR}"
copy_man man/url2file.1 "${MANDIR}"

# Install web form
if [ ! -d "${FORMDIR}" ]
then
	echo "Creating dir ${FORMDIR}."
	mkdir -p "${FORMDIR}"
	echo "You may need to set the permissions on ${FORMDIR}."
fi
if [ -f "${FORMDIR}/index.html" ]
then
	echo "${FORMDIR}/index.html exists."
	echo "Not installing."
else
	echo "Copying webform."
	cp search/index.html "${FORMDIR}/"
	echo "You may need to set the permissions on ${FORMDIR}/index.html."
fi

# Data dirs
if [ -d "${DATADIR}" ]
then
	echo "Dir ${DATADIR} exists."
else
	echo "Creating dir ${DATADIR}."
	mkdir -p "${DATADIR}"
	echo "Warning: You need to set the permissions on ${DATADIR}."
	echo "It has to be writable by the crawler process owner."
fi
if [ -d "${DATADIR}/index" ]
then
	echo "Dir ${DATADIR}/index exists."
else
	echo "Creating dir ${DATADIR}/index."
	mkdir "${DATADIR}/index"
	echo "Warning: You need to set the permissions on ${DATADIR}/index."
	echo "It has to be writable by the crawler process owner."
fi
if [ -d "${DATADIR}/index/bak" ]
then
	echo "Dir ${DATADIR}/index/bak exists."
else
	echo "Creating dir ${DATADIR}/index/bak."
	mkdir "${DATADIR}/index/bak"
	echo "Warning: You need to set the permissions on ${DATADIR}/index/bak."
	echo "It has to be writable by the crawler process owner."
fi
if [ -d "${DATADIR}/index/new" ]
then
	echo "Dir ${DATADIR}/index/new exists."
else
	echo "Creating dir ${DATADIR}/index/new."
	mkdir "${DATADIR}/index/new"
	echo "Warning: You need to set the permissions on ${DATADIR}/index/new."
	echo "It has to be writable by the crawler process owner."
fi

# Synonym files
echo "Copying synonym files"
cp -u synonyms/* "${DATADIR}/"

